@@ -10,7 +10,7 @@ import types
 
 from . import validators
 
-__version__ = "0.3.2"
+__version__ = "0.3.3"
 
 # constants for DeletionPolicy
 Delete = 'Delete'
@@ -176,7 +176,7 @@ class UpdatePolicy(BaseAWSObject):
 
 class AWSHelperFn(object):
     def getdata(self, data):
-        if isinstance(data, AWSObject):
+        if isinstance(data, BaseAWSObject):
             return data.name
         else:
             return data
